package de.tu_darmstadt.tk.SmartHomeNetworkSim.view.util;

import java.awt.Color;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.InputStream;

import javax.imageio.ImageIO;

/**
 * Class for various helper methods.
 *
 * @author Andreas T. Meyer-Berg
 */
public class Utility {

	/**
	 * Loads resource image from the given path (resources/path). Returns default
	 * image, if loading failed
	 * 
	 * @param path
	 *            path where the image is located
	 * @return Image from path, or default image if it failed
	 */
	public static BufferedImage loadFile(String path) {
		try {
			// Try loading Image from jar/resources
			InputStream i = path.getClass().getClassLoader()
					.getResourceAsStream(path);
			return ImageIO.read(i);
		} catch (Exception e) {
			// Try loading from absolute path, if it failed (e.g. starting the
			// program from eclipse or jvm)
			// extend path with path to resources
			path = "src/main/resources/" + path;
			try {
				return ImageIO.read(new File(path));
			} catch (Exception e2) {
				/**
				 * return default Image (red cross on white background)
				 */
				BufferedImage def = new BufferedImage(64, 64,
						BufferedImage.TYPE_INT_RGB);
				for (int i = 0; i < 64; i++)
					for (int j = 0; j < 64; j++) {
						if (i * (64 - i) - j * (64 - j) == 0)
							def.setRGB(i, j, Color.RED.getRGB());
						else
							def.setRGB(i, j, Color.white.getRGB());
					}
				return def;
			}
		}
	}
}
